# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.content_rating import ContentRating

class TestContentRating(unittest.TestCase):
    """ContentRating unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ContentRating:
        """Test ContentRating
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ContentRating`
        """
        model = ContentRating()
        if include_optional:
            return ContentRating(
                acb_rating = 'acbUnspecified',
                agcom_rating = 'agcomUnspecified',
                anatel_rating = 'anatelUnspecified',
                bbfc_rating = 'bbfcUnspecified',
                bfvc_rating = 'bfvcUnspecified',
                bmukk_rating = 'bmukkUnspecified',
                catv_rating = 'catvUnspecified',
                catvfr_rating = 'catvfrUnspecified',
                cbfc_rating = 'cbfcUnspecified',
                ccc_rating = 'cccUnspecified',
                cce_rating = 'cceUnspecified',
                chfilm_rating = 'chfilmUnspecified',
                chvrs_rating = 'chvrsUnspecified',
                cicf_rating = 'cicfUnspecified',
                cna_rating = 'cnaUnspecified',
                cnc_rating = 'cncUnspecified',
                csa_rating = 'csaUnspecified',
                cscf_rating = 'cscfUnspecified',
                czfilm_rating = 'czfilmUnspecified',
                djctq_rating = 'djctqUnspecified',
                djctq_rating_reasons = [
                    'djctqRatingReasonUnspecified'
                    ],
                ecbmct_rating = 'ecbmctUnspecified',
                eefilm_rating = 'eefilmUnspecified',
                egfilm_rating = 'egfilmUnspecified',
                eirin_rating = 'eirinUnspecified',
                fcbm_rating = 'fcbmUnspecified',
                fco_rating = 'fcoUnspecified',
                fmoc_rating = 'fmocUnspecified',
                fpb_rating = 'fpbUnspecified',
                fpb_rating_reasons = [
                    'fpbRatingReasonUnspecified'
                    ],
                fsk_rating = 'fskUnspecified',
                grfilm_rating = 'grfilmUnspecified',
                icaa_rating = 'icaaUnspecified',
                ifco_rating = 'ifcoUnspecified',
                ilfilm_rating = 'ilfilmUnspecified',
                incaa_rating = 'incaaUnspecified',
                kfcb_rating = 'kfcbUnspecified',
                kijkwijzer_rating = 'kijkwijzerUnspecified',
                kmrb_rating = 'kmrbUnspecified',
                lsf_rating = 'lsfUnspecified',
                mccaa_rating = 'mccaaUnspecified',
                mccyp_rating = 'mccypUnspecified',
                mcst_rating = 'mcstUnspecified',
                mda_rating = 'mdaUnspecified',
                medietilsynet_rating = 'medietilsynetUnspecified',
                meku_rating = 'mekuUnspecified',
                mena_mpaa_rating = 'menaMpaaUnspecified',
                mibac_rating = 'mibacUnspecified',
                moc_rating = 'mocUnspecified',
                moctw_rating = 'moctwUnspecified',
                mpaa_rating = 'mpaaUnspecified',
                mpaat_rating = 'mpaatUnspecified',
                mtrcb_rating = 'mtrcbUnspecified',
                nbc_rating = 'nbcUnspecified',
                nbcpl_rating = 'nbcplUnspecified',
                nfrc_rating = 'nfrcUnspecified',
                nfvcb_rating = 'nfvcbUnspecified',
                nkclv_rating = 'nkclvUnspecified',
                nmc_rating = 'nmcUnspecified',
                oflc_rating = 'oflcUnspecified',
                pefilm_rating = 'pefilmUnspecified',
                rcnof_rating = 'rcnofUnspecified',
                resorteviolencia_rating = 'resorteviolenciaUnspecified',
                rtc_rating = 'rtcUnspecified',
                rte_rating = 'rteUnspecified',
                russia_rating = 'russiaUnspecified',
                skfilm_rating = 'skfilmUnspecified',
                smais_rating = 'smaisUnspecified',
                smsa_rating = 'smsaUnspecified',
                tvpg_rating = 'tvpgUnspecified',
                yt_rating = 'ytUnspecified'
            )
        else:
            return ContentRating(
        )
        """

    def testContentRating(self):
        """Test ContentRating"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.search_result_snippet import SearchResultSnippet

class TestSearchResultSnippet(unittest.TestCase):
    """SearchResultSnippet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchResultSnippet:
        """Test SearchResultSnippet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchResultSnippet`
        """
        model = SearchResultSnippet()
        if include_optional:
            return SearchResultSnippet(
                channel_id = '',
                channel_title = '',
                description = '',
                live_broadcast_content = 'none',
                published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                thumbnails = youtube_ti.models.thumbnail_details.ThumbnailDetails(
                    default = youtube_ti.models.thumbnail.Thumbnail(
                        height = 56, 
                        url = '', 
                        width = 56, ), 
                    high = youtube_ti.models.thumbnail.Thumbnail(
                        height = 56, 
                        url = '', 
                        width = 56, ), 
                    maxres = , 
                    medium = , 
                    standard = , ),
                title = ''
            )
        else:
            return SearchResultSnippet(
        )
        """

    def testSearchResultSnippet(self):
        """Test SearchResultSnippet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from youtube_ti.models.video_processing_details_processing_progress import VideoProcessingDetailsProcessingProgress
from typing import Optional, Set
from typing_extensions import Self

class VideoProcessingDetails(BaseModel):
    """
    Describes processing status and progress and availability of some other Video resource parts.
    """ # noqa: E501
    editor_suggestions_availability: Optional[StrictStr] = Field(default=None, description="This value indicates whether video editing suggestions, which might improve video quality or the playback experience, are available for the video. You can retrieve these suggestions by requesting the suggestions part in your videos.list() request.", alias="editorSuggestionsAvailability")
    file_details_availability: Optional[StrictStr] = Field(default=None, description="This value indicates whether file details are available for the uploaded video. You can retrieve a video's file details by requesting the fileDetails part in your videos.list() request.", alias="fileDetailsAvailability")
    processing_failure_reason: Optional[StrictStr] = Field(default=None, description="The reason that YouTube failed to process the video. This property will only have a value if the processingStatus property's value is failed.", alias="processingFailureReason")
    processing_issues_availability: Optional[StrictStr] = Field(default=None, description="This value indicates whether the video processing engine has generated suggestions that might improve YouTube's ability to process the the video, warnings that explain video processing problems, or errors that cause video processing problems. You can retrieve these suggestions by requesting the suggestions part in your videos.list() request.", alias="processingIssuesAvailability")
    processing_progress: Optional[VideoProcessingDetailsProcessingProgress] = Field(default=None, alias="processingProgress")
    processing_status: Optional[StrictStr] = Field(default=None, description="The video's processing status. This value indicates whether YouTube was able to process the video or if the video is still being processed.", alias="processingStatus")
    tag_suggestions_availability: Optional[StrictStr] = Field(default=None, description="This value indicates whether keyword (tag) suggestions are available for the video. Tags can be added to a video's metadata to make it easier for other users to find the video. You can retrieve these suggestions by requesting the suggestions part in your videos.list() request.", alias="tagSuggestionsAvailability")
    thumbnails_availability: Optional[StrictStr] = Field(default=None, description="This value indicates whether thumbnail images have been generated for the video.", alias="thumbnailsAvailability")
    __properties: ClassVar[List[str]] = ["editorSuggestionsAvailability", "fileDetailsAvailability", "processingFailureReason", "processingIssuesAvailability", "processingProgress", "processingStatus", "tagSuggestionsAvailability", "thumbnailsAvailability"]

    @field_validator('processing_failure_reason')
    def processing_failure_reason_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['uploadFailed', 'transcodeFailed', 'streamingFailed', 'other']):
            raise ValueError("must be one of enum values ('uploadFailed', 'transcodeFailed', 'streamingFailed', 'other')")
        return value

    @field_validator('processing_status')
    def processing_status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['processing', 'succeeded', 'failed', 'terminated']):
            raise ValueError("must be one of enum values ('processing', 'succeeded', 'failed', 'terminated')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VideoProcessingDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of processing_progress
        if self.processing_progress:
            _dict['processingProgress'] = self.processing_progress.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VideoProcessingDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "editorSuggestionsAvailability": obj.get("editorSuggestionsAvailability"),
            "fileDetailsAvailability": obj.get("fileDetailsAvailability"),
            "processingFailureReason": obj.get("processingFailureReason"),
            "processingIssuesAvailability": obj.get("processingIssuesAvailability"),
            "processingProgress": VideoProcessingDetailsProcessingProgress.from_dict(obj["processingProgress"]) if obj.get("processingProgress") is not None else None,
            "processingStatus": obj.get("processingStatus"),
            "tagSuggestionsAvailability": obj.get("tagSuggestionsAvailability"),
            "thumbnailsAvailability": obj.get("thumbnailsAvailability")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class VideoLiveStreamingDetails(BaseModel):
    """
    Details about the live streaming metadata.
    """ # noqa: E501
    active_live_chat_id: Optional[StrictStr] = Field(default=None, description="The ID of the currently active live chat attached to this video. This field is filled only if the video is a currently live broadcast that has live chat. Once the broadcast transitions to complete this field will be removed and the live chat closed down. For persistent broadcasts that live chat id will no longer be tied to this video but rather to the new video being displayed at the persistent page.", alias="activeLiveChatId")
    actual_end_time: Optional[datetime] = Field(default=None, description="The time that the broadcast actually ended. This value will not be available until the broadcast is over.", alias="actualEndTime")
    actual_start_time: Optional[datetime] = Field(default=None, description="The time that the broadcast actually started. This value will not be available until the broadcast begins.", alias="actualStartTime")
    concurrent_viewers: Optional[StrictStr] = Field(default=None, description="The number of viewers currently watching the broadcast. The property and its value will be present if the broadcast has current viewers and the broadcast owner has not hidden the viewcount for the video. Note that YouTube stops tracking the number of concurrent viewers for a broadcast when the broadcast ends. So, this property would not identify the number of viewers watching an archived video of a live broadcast that already ended.", alias="concurrentViewers")
    scheduled_end_time: Optional[datetime] = Field(default=None, description="The time that the broadcast is scheduled to end. If the value is empty or the property is not present, then the broadcast is scheduled to continue indefinitely.", alias="scheduledEndTime")
    scheduled_start_time: Optional[datetime] = Field(default=None, description="The time that the broadcast is scheduled to begin.", alias="scheduledStartTime")
    __properties: ClassVar[List[str]] = ["activeLiveChatId", "actualEndTime", "actualStartTime", "concurrentViewers", "scheduledEndTime", "scheduledStartTime"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VideoLiveStreamingDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VideoLiveStreamingDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "activeLiveChatId": obj.get("activeLiveChatId"),
            "actualEndTime": obj.get("actualEndTime"),
            "actualStartTime": obj.get("actualStartTime"),
            "concurrentViewers": obj.get("concurrentViewers"),
            "scheduledEndTime": obj.get("scheduledEndTime"),
            "scheduledStartTime": obj.get("scheduledStartTime")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from youtube_ti.models.ingestion_info import IngestionInfo
from typing import Optional, Set
from typing_extensions import Self

class CdnSettings(BaseModel):
    """
    Brief description of the live stream cdn settings.
    """ # noqa: E501
    format: Optional[StrictStr] = Field(default=None, description="The format of the video stream that you are sending to Youtube. ")
    frame_rate: Optional[StrictStr] = Field(default=None, description="The frame rate of the inbound video data.", alias="frameRate")
    ingestion_info: Optional[IngestionInfo] = Field(default=None, alias="ingestionInfo")
    ingestion_type: Optional[StrictStr] = Field(default=None, description=" The method or protocol used to transmit the video stream.", alias="ingestionType")
    resolution: Optional[StrictStr] = Field(default=None, description="The resolution of the inbound video data.")
    __properties: ClassVar[List[str]] = ["format", "frameRate", "ingestionInfo", "ingestionType", "resolution"]

    @field_validator('frame_rate')
    def frame_rate_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['30fps', '60fps', 'variable']):
            raise ValueError("must be one of enum values ('30fps', '60fps', 'variable')")
        return value

    @field_validator('ingestion_type')
    def ingestion_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['rtmp', 'dash', 'webrtc', 'hls']):
            raise ValueError("must be one of enum values ('rtmp', 'dash', 'webrtc', 'hls')")
        return value

    @field_validator('resolution')
    def resolution_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['240p', '360p', '480p', '720p', '1080p', '1440p', '2160p', 'variable']):
            raise ValueError("must be one of enum values ('240p', '360p', '480p', '720p', '1080p', '1440p', '2160p', 'variable')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CdnSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of ingestion_info
        if self.ingestion_info:
            _dict['ingestionInfo'] = self.ingestion_info.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CdnSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "format": obj.get("format"),
            "frameRate": obj.get("frameRate"),
            "ingestionInfo": IngestionInfo.from_dict(obj["ingestionInfo"]) if obj.get("ingestionInfo") is not None else None,
            "ingestionType": obj.get("ingestionType"),
            "resolution": obj.get("resolution")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.live_broadcast_content_details import LiveBroadcastContentDetails

class TestLiveBroadcastContentDetails(unittest.TestCase):
    """LiveBroadcastContentDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LiveBroadcastContentDetails:
        """Test LiveBroadcastContentDetails
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LiveBroadcastContentDetails`
        """
        model = LiveBroadcastContentDetails()
        if include_optional:
            return LiveBroadcastContentDetails(
                bound_stream_id = '',
                bound_stream_last_update_time_ms = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                closed_captions_type = 'closedCaptionsTypeUnspecified',
                enable_auto_start = True,
                enable_auto_stop = True,
                enable_closed_captions = True,
                enable_content_encryption = True,
                enable_dvr = True,
                enable_embed = True,
                enable_low_latency = True,
                latency_preference = 'latencyPreferenceUnspecified',
                mesh = 'YQ==',
                monitor_stream = youtube_ti.models.monitor_stream_info.MonitorStreamInfo(
                    broadcast_stream_delay_ms = 56, 
                    embed_html = '', 
                    enable_monitor_stream = True, ),
                projection = 'projectionUnspecified',
                record_from_start = True,
                start_with_slate = True,
                stereo_layout = 'stereoLayoutUnspecified'
            )
        else:
            return LiveBroadcastContentDetails(
        )
        """

    def testLiveBroadcastContentDetails(self):
        """Test LiveBroadcastContentDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class MonitorStreamInfo(BaseModel):
    """
    Settings and Info of the monitor stream
    """ # noqa: E501
    broadcast_stream_delay_ms: Optional[StrictInt] = Field(default=None, description="If you have set the enableMonitorStream property to true, then this property determines the length of the live broadcast delay.", alias="broadcastStreamDelayMs")
    embed_html: Optional[StrictStr] = Field(default=None, description="HTML code that embeds a player that plays the monitor stream.", alias="embedHtml")
    enable_monitor_stream: Optional[StrictBool] = Field(default=None, description="This value determines whether the monitor stream is enabled for the broadcast. If the monitor stream is enabled, then YouTube will broadcast the event content on a special stream intended only for the broadcaster's consumption. The broadcaster can use the stream to review the event content and also to identify the optimal times to insert cuepoints. You need to set this value to true if you intend to have a broadcast delay for your event. *Note:* This property cannot be updated once the broadcast is in the testing or live state.", alias="enableMonitorStream")
    __properties: ClassVar[List[str]] = ["broadcastStreamDelayMs", "embedHtml", "enableMonitorStream"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MonitorStreamInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MonitorStreamInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "broadcastStreamDelayMs": obj.get("broadcastStreamDelayMs"),
            "embedHtml": obj.get("embedHtml"),
            "enableMonitorStream": obj.get("enableMonitorStream")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from youtube_ti.models.channel_to_store_link_details_billing_details import ChannelToStoreLinkDetailsBillingDetails
from youtube_ti.models.channel_to_store_link_details_merchant_affiliate_program_details import ChannelToStoreLinkDetailsMerchantAffiliateProgramDetails
from typing import Optional, Set
from typing_extensions import Self

class ChannelToStoreLinkDetails(BaseModel):
    """
    Information specific to a store on a merchandising platform linked to a YouTube channel.
    """ # noqa: E501
    billing_details: Optional[ChannelToStoreLinkDetailsBillingDetails] = Field(default=None, alias="billingDetails")
    merchant_affiliate_program_details: Optional[ChannelToStoreLinkDetailsMerchantAffiliateProgramDetails] = Field(default=None, alias="merchantAffiliateProgramDetails")
    merchant_id: Optional[StrictStr] = Field(default=None, description="Google Merchant Center id of the store.", alias="merchantId")
    store_name: Optional[StrictStr] = Field(default=None, description="Name of the store.", alias="storeName")
    store_url: Optional[StrictStr] = Field(default=None, description="Landing page of the store.", alias="storeUrl")
    __properties: ClassVar[List[str]] = ["billingDetails", "merchantAffiliateProgramDetails", "merchantId", "storeName", "storeUrl"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChannelToStoreLinkDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of billing_details
        if self.billing_details:
            _dict['billingDetails'] = self.billing_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of merchant_affiliate_program_details
        if self.merchant_affiliate_program_details:
            _dict['merchantAffiliateProgramDetails'] = self.merchant_affiliate_program_details.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChannelToStoreLinkDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "billingDetails": ChannelToStoreLinkDetailsBillingDetails.from_dict(obj["billingDetails"]) if obj.get("billingDetails") is not None else None,
            "merchantAffiliateProgramDetails": ChannelToStoreLinkDetailsMerchantAffiliateProgramDetails.from_dict(obj["merchantAffiliateProgramDetails"]) if obj.get("merchantAffiliateProgramDetails") is not None else None,
            "merchantId": obj.get("merchantId"),
            "storeName": obj.get("storeName"),
            "storeUrl": obj.get("storeUrl")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.live_broadcast import LiveBroadcast

class TestLiveBroadcast(unittest.TestCase):
    """LiveBroadcast unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LiveBroadcast:
        """Test LiveBroadcast
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LiveBroadcast`
        """
        model = LiveBroadcast()
        if include_optional:
            return LiveBroadcast(
                content_details = youtube_ti.models.live_broadcast_content_details.LiveBroadcastContentDetails(
                    bound_stream_id = '', 
                    bound_stream_last_update_time_ms = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    closed_captions_type = 'closedCaptionsTypeUnspecified', 
                    enable_auto_start = True, 
                    enable_auto_stop = True, 
                    enable_closed_captions = True, 
                    enable_content_encryption = True, 
                    enable_dvr = True, 
                    enable_embed = True, 
                    enable_low_latency = True, 
                    latency_preference = 'latencyPreferenceUnspecified', 
                    mesh = 'YQ==', 
                    monitor_stream = youtube_ti.models.monitor_stream_info.MonitorStreamInfo(
                        broadcast_stream_delay_ms = 56, 
                        embed_html = '', 
                        enable_monitor_stream = True, ), 
                    projection = 'projectionUnspecified', 
                    record_from_start = True, 
                    start_with_slate = True, 
                    stereo_layout = 'stereoLayoutUnspecified', ),
                etag = '',
                id = '',
                kind = 'youtube#liveBroadcast',
                monetization_details = youtube_ti.models.live_broadcast_monetization_details.LiveBroadcastMonetizationDetails(
                    cuepoint_schedule = youtube_ti.models.cuepoint_schedule.CuepointSchedule(
                        enabled = True, 
                        pause_ads_until = '', 
                        repeat_interval_secs = 56, 
                        schedule_strategy = 'scheduleStrategyUnspecified', ), ),
                snippet = youtube_ti.models.live_broadcast_snippet.LiveBroadcastSnippet(
                    actual_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    actual_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    channel_id = '', 
                    description = '', 
                    is_default_broadcast = True, 
                    live_chat_id = '', 
                    published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    scheduled_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    scheduled_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    thumbnails = youtube_ti.models.thumbnail_details.ThumbnailDetails(
                        default = youtube_ti.models.thumbnail.Thumbnail(
                            height = 56, 
                            url = '', 
                            width = 56, ), 
                        high = youtube_ti.models.thumbnail.Thumbnail(
                            height = 56, 
                            url = '', 
                            width = 56, ), 
                        maxres = , 
                        medium = , 
                        standard = , ), 
                    title = '', ),
                statistics = youtube_ti.models.live_broadcast_statistics.LiveBroadcastStatistics(
                    concurrent_viewers = '', ),
                status = youtube_ti.models.live_broadcast_status.LiveBroadcastStatus(
                    life_cycle_status = 'lifeCycleStatusUnspecified', 
                    live_broadcast_priority = 'liveBroadcastPriorityUnspecified', 
                    made_for_kids = True, 
                    privacy_status = 'public', 
                    recording_status = 'liveBroadcastRecordingStatusUnspecified', 
                    self_declared_made_for_kids = True, )
            )
        else:
            return LiveBroadcast(
        )
        """

    def testLiveBroadcast(self):
        """Test LiveBroadcast"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.live_stream_list_response import LiveStreamListResponse

class TestLiveStreamListResponse(unittest.TestCase):
    """LiveStreamListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LiveStreamListResponse:
        """Test LiveStreamListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LiveStreamListResponse`
        """
        model = LiveStreamListResponse()
        if include_optional:
            return LiveStreamListResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.live_stream.LiveStream(
                        cdn = youtube_ti.models.cdn_settings.CdnSettings(
                            format = '', 
                            frame_rate = '30fps', 
                            ingestion_info = youtube_ti.models.ingestion_info.IngestionInfo(
                                backup_ingestion_address = '', 
                                ingestion_address = '', 
                                rtmps_backup_ingestion_address = '', 
                                rtmps_ingestion_address = '', 
                                stream_name = '', ), 
                            ingestion_type = 'rtmp', 
                            resolution = '240p', ), 
                        content_details = youtube_ti.models.live_stream_content_details.LiveStreamContentDetails(
                            closed_captions_ingestion_url = '', 
                            is_reusable = True, ), 
                        etag = '', 
                        id = '', 
                        kind = 'youtube#liveStream', 
                        snippet = youtube_ti.models.live_stream_snippet.LiveStreamSnippet(
                            channel_id = '', 
                            description = '', 
                            is_default_stream = True, 
                            published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            title = '', ), 
                        status = youtube_ti.models.live_stream_status.LiveStreamStatus(
                            health_status = youtube_ti.models.live_stream_health_status.LiveStreamHealthStatus(
                                configuration_issues = [
                                    youtube_ti.models.live_stream_configuration_issue.LiveStreamConfigurationIssue(
                                        description = '', 
                                        reason = '', 
                                        severity = 'info', 
                                        type = 'gopSizeOver', )
                                    ], 
                                last_update_time_seconds = '', ), 
                            stream_status = 'created', ), )
                    ],
                kind = 'youtube#liveStreamListResponse',
                next_page_token = '',
                page_info = youtube_ti.models.page_info.PageInfo(
                    results_per_page = 56, 
                    total_results = 56, ),
                prev_page_token = '',
                token_pagination = None,
                visitor_id = ''
            )
        else:
            return LiveStreamListResponse(
        )
        """

    def testLiveStreamListResponse(self):
        """Test LiveStreamListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class VideoFileDetailsVideoStream(BaseModel):
    """
    Information about a video stream.
    """ # noqa: E501
    aspect_ratio: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The video content's display aspect ratio, which specifies the aspect ratio in which the video should be displayed.", alias="aspectRatio")
    bitrate_bps: Optional[StrictStr] = Field(default=None, description="The video stream's bitrate, in bits per second.", alias="bitrateBps")
    codec: Optional[StrictStr] = Field(default=None, description="The video codec that the stream uses.")
    frame_rate_fps: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The video stream's frame rate, in frames per second.", alias="frameRateFps")
    height_pixels: Optional[StrictInt] = Field(default=None, description="The encoded video content's height in pixels.", alias="heightPixels")
    rotation: Optional[StrictStr] = Field(default=None, description="The amount that YouTube needs to rotate the original source content to properly display the video.")
    vendor: Optional[StrictStr] = Field(default=None, description="A value that uniquely identifies a video vendor. Typically, the value is a four-letter vendor code.")
    width_pixels: Optional[StrictInt] = Field(default=None, description="The encoded video content's width in pixels. You can calculate the video's encoding aspect ratio as width_pixels / height_pixels.", alias="widthPixels")
    __properties: ClassVar[List[str]] = ["aspectRatio", "bitrateBps", "codec", "frameRateFps", "heightPixels", "rotation", "vendor", "widthPixels"]

    @field_validator('rotation')
    def rotation_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['none', 'clockwise', 'upsideDown', 'counterClockwise', 'other']):
            raise ValueError("must be one of enum values ('none', 'clockwise', 'upsideDown', 'counterClockwise', 'other')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VideoFileDetailsVideoStream from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VideoFileDetailsVideoStream from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "aspectRatio": obj.get("aspectRatio"),
            "bitrateBps": obj.get("bitrateBps"),
            "codec": obj.get("codec"),
            "frameRateFps": obj.get("frameRateFps"),
            "heightPixels": obj.get("heightPixels"),
            "rotation": obj.get("rotation"),
            "vendor": obj.get("vendor"),
            "widthPixels": obj.get("widthPixels")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class LiveBroadcastStatus(BaseModel):
    """
    Live broadcast state.
    """ # noqa: E501
    life_cycle_status: Optional[StrictStr] = Field(default=None, description="The broadcast's status. The status can be updated using the API's liveBroadcasts.transition method.", alias="lifeCycleStatus")
    live_broadcast_priority: Optional[StrictStr] = Field(default=None, description="Priority of the live broadcast event (internal state).", alias="liveBroadcastPriority")
    made_for_kids: Optional[StrictBool] = Field(default=None, description="Whether the broadcast is made for kids or not, decided by YouTube instead of the creator. This field is read only.", alias="madeForKids")
    privacy_status: Optional[StrictStr] = Field(default=None, description="The broadcast's privacy status. Note that the broadcast represents exactly one YouTube video, so the privacy settings are identical to those supported for videos. In addition, you can set this field by modifying the broadcast resource or by setting the privacyStatus field of the corresponding video resource.", alias="privacyStatus")
    recording_status: Optional[StrictStr] = Field(default=None, description="The broadcast's recording status.", alias="recordingStatus")
    self_declared_made_for_kids: Optional[StrictBool] = Field(default=None, description="This field will be set to True if the creator declares the broadcast to be kids only: go/live-cw-work.", alias="selfDeclaredMadeForKids")
    __properties: ClassVar[List[str]] = ["lifeCycleStatus", "liveBroadcastPriority", "madeForKids", "privacyStatus", "recordingStatus", "selfDeclaredMadeForKids"]

    @field_validator('life_cycle_status')
    def life_cycle_status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['lifeCycleStatusUnspecified', 'created', 'ready', 'testing', 'live', 'complete', 'revoked', 'testStarting', 'liveStarting']):
            raise ValueError("must be one of enum values ('lifeCycleStatusUnspecified', 'created', 'ready', 'testing', 'live', 'complete', 'revoked', 'testStarting', 'liveStarting')")
        return value

    @field_validator('live_broadcast_priority')
    def live_broadcast_priority_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['liveBroadcastPriorityUnspecified', 'low', 'normal', 'high']):
            raise ValueError("must be one of enum values ('liveBroadcastPriorityUnspecified', 'low', 'normal', 'high')")
        return value

    @field_validator('privacy_status')
    def privacy_status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['public', 'unlisted', 'private']):
            raise ValueError("must be one of enum values ('public', 'unlisted', 'private')")
        return value

    @field_validator('recording_status')
    def recording_status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['liveBroadcastRecordingStatusUnspecified', 'notRecording', 'recording', 'recorded']):
            raise ValueError("must be one of enum values ('liveBroadcastRecordingStatusUnspecified', 'notRecording', 'recording', 'recorded')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LiveBroadcastStatus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LiveBroadcastStatus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "lifeCycleStatus": obj.get("lifeCycleStatus"),
            "liveBroadcastPriority": obj.get("liveBroadcastPriority"),
            "madeForKids": obj.get("madeForKids"),
            "privacyStatus": obj.get("privacyStatus"),
            "recordingStatus": obj.get("recordingStatus"),
            "selfDeclaredMadeForKids": obj.get("selfDeclaredMadeForKids")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.channel_settings import ChannelSettings

class TestChannelSettings(unittest.TestCase):
    """ChannelSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChannelSettings:
        """Test ChannelSettings
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChannelSettings`
        """
        model = ChannelSettings()
        if include_optional:
            return ChannelSettings(
                country = '',
                default_language = '',
                default_tab = '',
                description = '',
                featured_channels_title = '',
                featured_channels_urls = [
                    ''
                    ],
                keywords = '',
                moderate_comments = True,
                profile_color = '',
                show_browse_view = True,
                show_related_channels = True,
                title = '',
                tracking_analytics_account_id = '',
                unsubscribed_trailer = ''
            )
        else:
            return ChannelSettings(
        )
        """

    def testChannelSettings(self):
        """Test ChannelSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.member_list_response import MemberListResponse

class TestMemberListResponse(unittest.TestCase):
    """MemberListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MemberListResponse:
        """Test MemberListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MemberListResponse`
        """
        model = MemberListResponse()
        if include_optional:
            return MemberListResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.member.Member(
                        etag = '', 
                        kind = 'youtube#member', 
                        snippet = youtube_ti.models.member_snippet.MemberSnippet(
                            creator_channel_id = '', 
                            member_details = youtube_ti.models.channel_profile_details.ChannelProfileDetails(
                                channel_id = '', 
                                channel_url = '', 
                                display_name = '', 
                                profile_image_url = '', ), 
                            memberships_details = youtube_ti.models.memberships_details.MembershipsDetails(
                                accessible_levels = [
                                    ''
                                    ], 
                                highest_accessible_level = '', 
                                highest_accessible_level_display_name = '', 
                                memberships_duration = youtube_ti.models.memberships_duration.MembershipsDuration(
                                    member_since = '', 
                                    member_total_duration_months = 56, ), 
                                memberships_duration_at_levels = [
                                    youtube_ti.models.memberships_duration_at_level.MembershipsDurationAtLevel(
                                        level = '', 
                                        member_since = '', 
                                        member_total_duration_months = 56, )
                                    ], ), ), )
                    ],
                kind = 'youtube#memberListResponse',
                next_page_token = '',
                page_info = youtube_ti.models.page_info.PageInfo(
                    results_per_page = 56, 
                    total_results = 56, ),
                token_pagination = None,
                visitor_id = ''
            )
        else:
            return MemberListResponse(
        )
        """

    def testMemberListResponse(self):
        """Test MemberListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.channel_section import ChannelSection

class TestChannelSection(unittest.TestCase):
    """ChannelSection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChannelSection:
        """Test ChannelSection
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChannelSection`
        """
        model = ChannelSection()
        if include_optional:
            return ChannelSection(
                content_details = youtube_ti.models.channel_section_content_details.ChannelSectionContentDetails(
                    channels = [
                        ''
                        ], 
                    playlists = [
                        ''
                        ], ),
                etag = '',
                id = '',
                kind = 'youtube#channelSection',
                localizations = None,
                snippet = youtube_ti.models.channel_section_snippet.ChannelSectionSnippet(
                    channel_id = '', 
                    default_language = '', 
                    localized = youtube_ti.models.channel_section_localization.ChannelSectionLocalization(
                        title = '', ), 
                    position = 56, 
                    style = 'channelsectionStyleUnspecified', 
                    title = '', 
                    type = 'channelsectionTypeUndefined', ),
                targeting = youtube_ti.models.channel_section_targeting.ChannelSectionTargeting(
                    countries = [
                        ''
                        ], 
                    languages = [
                        ''
                        ], 
                    regions = [
                        ''
                        ], )
            )
        else:
            return ChannelSection(
        )
        """

    def testChannelSection(self):
        """Test ChannelSection"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from youtube_ti.models.video_suggestions_tag_suggestion import VideoSuggestionsTagSuggestion
from typing import Optional, Set
from typing_extensions import Self

class VideoSuggestions(BaseModel):
    """
    Specifies suggestions on how to improve video content, including encoding hints, tag suggestions, and editor suggestions.
    """ # noqa: E501
    editor_suggestions: Optional[List[StrictStr]] = Field(default=None, description="A list of video editing operations that might improve the video quality or playback experience of the uploaded video.", alias="editorSuggestions")
    processing_errors: Optional[List[StrictStr]] = Field(default=None, description="A list of errors that will prevent YouTube from successfully processing the uploaded video video. These errors indicate that, regardless of the video's current processing status, eventually, that status will almost certainly be failed.", alias="processingErrors")
    processing_hints: Optional[List[StrictStr]] = Field(default=None, description="A list of suggestions that may improve YouTube's ability to process the video.", alias="processingHints")
    processing_warnings: Optional[List[StrictStr]] = Field(default=None, description="A list of reasons why YouTube may have difficulty transcoding the uploaded video or that might result in an erroneous transcoding. These warnings are generated before YouTube actually processes the uploaded video file. In addition, they identify issues that are unlikely to cause the video processing to fail but that might cause problems such as sync issues, video artifacts, or a missing audio track.", alias="processingWarnings")
    tag_suggestions: Optional[List[VideoSuggestionsTagSuggestion]] = Field(default=None, description="A list of keyword tags that could be added to the video's metadata to increase the likelihood that users will locate your video when searching or browsing on YouTube.", alias="tagSuggestions")
    __properties: ClassVar[List[str]] = ["editorSuggestions", "processingErrors", "processingHints", "processingWarnings", "tagSuggestions"]

    @field_validator('editor_suggestions')
    def editor_suggestions_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(['videoAutoLevels', 'videoStabilize', 'videoCrop', 'audioQuietAudioSwap']):
                raise ValueError("each list item must be one of ('videoAutoLevels', 'videoStabilize', 'videoCrop', 'audioQuietAudioSwap')")
        return value

    @field_validator('processing_errors')
    def processing_errors_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(['audioFile', 'imageFile', 'projectFile', 'notAVideoFile', 'docFile', 'archiveFile', 'unsupportedSpatialAudioLayout']):
                raise ValueError("each list item must be one of ('audioFile', 'imageFile', 'projectFile', 'notAVideoFile', 'docFile', 'archiveFile', 'unsupportedSpatialAudioLayout')")
        return value

    @field_validator('processing_hints')
    def processing_hints_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(['nonStreamableMov', 'sendBestQualityVideo', 'sphericalVideo', 'spatialAudio', 'vrVideo', 'hdrVideo']):
                raise ValueError("each list item must be one of ('nonStreamableMov', 'sendBestQualityVideo', 'sphericalVideo', 'spatialAudio', 'vrVideo', 'hdrVideo')")
        return value

    @field_validator('processing_warnings')
    def processing_warnings_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(['unknownContainer', 'unknownVideoCodec', 'unknownAudioCodec', 'inconsistentResolution', 'hasEditlist', 'problematicVideoCodec', 'problematicAudioCodec', 'unsupportedVrStereoMode', 'unsupportedSphericalProjectionType', 'unsupportedHdrPixelFormat', 'unsupportedHdrColorMetadata', 'problematicHdrLookupTable']):
                raise ValueError("each list item must be one of ('unknownContainer', 'unknownVideoCodec', 'unknownAudioCodec', 'inconsistentResolution', 'hasEditlist', 'problematicVideoCodec', 'problematicAudioCodec', 'unsupportedVrStereoMode', 'unsupportedSphericalProjectionType', 'unsupportedHdrPixelFormat', 'unsupportedHdrColorMetadata', 'problematicHdrLookupTable')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VideoSuggestions from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in tag_suggestions (list)
        _items = []
        if self.tag_suggestions:
            for _item_tag_suggestions in self.tag_suggestions:
                if _item_tag_suggestions:
                    _items.append(_item_tag_suggestions.to_dict())
            _dict['tagSuggestions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VideoSuggestions from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "editorSuggestions": obj.get("editorSuggestions"),
            "processingErrors": obj.get("processingErrors"),
            "processingHints": obj.get("processingHints"),
            "processingWarnings": obj.get("processingWarnings"),
            "tagSuggestions": [VideoSuggestionsTagSuggestion.from_dict(_item) for _item in obj["tagSuggestions"]] if obj.get("tagSuggestions") is not None else None
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr, field_validator
from typing import List, Optional
from typing_extensions import Annotated
from youtube_ti.models.channel import Channel
from youtube_ti.models.channel_list_response import ChannelListResponse

from youtube_ti.api_client import ApiClient, RequestSerialized
from youtube_ti.api_response import ApiResponse
from youtube_ti.rest import RESTResponseType


class ChannelsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def youtube_channels_list(
        self,
        part: Annotated[List[StrictStr], Field(description="The *part* parameter specifies a comma-separated list of one or more channel resource properties that the API response will include. If the parameter identifies a property that contains child properties, the child properties will be included in the response. For example, in a channel resource, the contentDetails property contains other properties, such as the uploads properties. As such, if you set *part=contentDetails*, the API response will also contain all of those nested properties.")],
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        category_id: Annotated[Optional[StrictStr], Field(description="Return the channels within the specified guide category ID.")] = None,
        for_handle: Annotated[Optional[StrictStr], Field(description="Return the channel associated with a YouTube handle.")] = None,
        for_username: Annotated[Optional[StrictStr], Field(description="Return the channel associated with a YouTube username.")] = None,
        hl: Annotated[Optional[StrictStr], Field(description="Stands for \"host language\". Specifies the localization language of the metadata to be filled into snippet.localized. The field is filled with the default metadata if there is no localization in the specified language. The parameter value must be a language code included in the list returned by the i18nLanguages.list method (e.g. en_US, es_MX).")] = None,
        id: Annotated[Optional[List[StrictStr]], Field(description="Return the channels with the specified IDs.")] = None,
        managed_by_me: Annotated[Optional[StrictBool], Field(description="Return the channels managed by the authenticated user.")] = None,
        max_results: Annotated[Optional[Annotated[int, Field(le=50, strict=True, ge=0)]], Field(description="The *maxResults* parameter specifies the maximum number of items that should be returned in the result set.")] = None,
        mine: Annotated[Optional[StrictBool], Field(description="Return the ids of channels owned by the authenticated user.")] = None,
        my_subscribers: Annotated[Optional[StrictBool], Field(description="Return the channels subscribed to the authenticated user")] = None,
        on_behalf_of_content_owner: Annotated[Optional[StrictStr], Field(description="*Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.")] = None,
        page_token: Annotated[Optional[StrictStr], Field(description="The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken and prevPageToken properties identify other pages that could be retrieved.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ChannelListResponse:
        """youtube_channels_list

        Retrieves a list of resources, possibly filtered.

        :param part: The *part* parameter specifies a comma-separated list of one or more channel resource properties that the API response will include. If the parameter identifies a property that contains child properties, the child properties will be included in the response. For example, in a channel resource, the contentDetails property contains other properties, such as the uploads properties. As such, if you set *part=contentDetails*, the API response will also contain all of those nested properties. (required)
        :type part: List[str]
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param category_id: Return the channels within the specified guide category ID.
        :type category_id: str
        :param for_handle: Return the channel associated with a YouTube handle.
        :type for_handle: str
        :param for_username: Return the channel associated with a YouTube username.
        :type for_username: str
        :param hl: Stands for \"host language\". Specifies the localization language of the metadata to be filled into snippet.localized. The field is filled with the default metadata if there is no localization in the specified language. The parameter value must be a language code included in the list returned by the i18nLanguages.list method (e.g. en_US, es_MX).
        :type hl: str
        :param id: Return the channels with the specified IDs.
        :type id: List[str]
        :param managed_by_me: Return the channels managed by the authenticated user.
        :type managed_by_me: bool
        :param max_results: The *maxResults* parameter specifies the maximum number of items that should be returned in the result set.
        :type max_results: int
        :param mine: Return the ids of channels owned by the authenticated user.
        :type mine: bool
        :param my_subscribers: Return the channels subscribed to the authenticated user
        :type my_subscribers: bool
        :param on_behalf_of_content_owner: *Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.
        :type on_behalf_of_content_owner: str
        :param page_token: The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken and prevPageToken properties identify other pages that could be retrieved.
        :type page_token: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_channels_list_serialize(
            part=part,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            category_id=category_id,
            for_handle=for_handle,
            for_username=for_username,
            hl=hl,
            id=id,
            managed_by_me=managed_by_me,
            max_results=max_results,
            mine=mine,
            my_subscribers=my_subscribers,
            on_behalf_of_content_owner=on_behalf_of_content_owner,
            page_token=page_token,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ChannelListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def youtube_channels_list_with_http_info(
        self,
        part: Annotated[List[StrictStr], Field(description="The *part* parameter specifies a comma-separated list of one or more channel resource properties that the API response will include. If the parameter identifies a property that contains child properties, the child properties will be included in the response. For example, in a channel resource, the contentDetails property contains other properties, such as the uploads properties. As such, if you set *part=contentDetails*, the API response will also contain all of those nested properties.")],
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        category_id: Annotated[Optional[StrictStr], Field(description="Return the channels within the specified guide category ID.")] = None,
        for_handle: Annotated[Optional[StrictStr], Field(description="Return the channel associated with a YouTube handle.")] = None,
        for_username: Annotated[Optional[StrictStr], Field(description="Return the channel associated with a YouTube username.")] = None,
        hl: Annotated[Optional[StrictStr], Field(description="Stands for \"host language\". Specifies the localization language of the metadata to be filled into snippet.localized. The field is filled with the default metadata if there is no localization in the specified language. The parameter value must be a language code included in the list returned by the i18nLanguages.list method (e.g. en_US, es_MX).")] = None,
        id: Annotated[Optional[List[StrictStr]], Field(description="Return the channels with the specified IDs.")] = None,
        managed_by_me: Annotated[Optional[StrictBool], Field(description="Return the channels managed by the authenticated user.")] = None,
        max_results: Annotated[Optional[Annotated[int, Field(le=50, strict=True, ge=0)]], Field(description="The *maxResults* parameter specifies the maximum number of items that should be returned in the result set.")] = None,
        mine: Annotated[Optional[StrictBool], Field(description="Return the ids of channels owned by the authenticated user.")] = None,
        my_subscribers: Annotated[Optional[StrictBool], Field(description="Return the channels subscribed to the authenticated user")] = None,
        on_behalf_of_content_owner: Annotated[Optional[StrictStr], Field(description="*Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.")] = None,
        page_token: Annotated[Optional[StrictStr], Field(description="The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken and prevPageToken properties identify other pages that could be retrieved.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[ChannelListResponse]:
        """youtube_channels_list

        Retrieves a list of resources, possibly filtered.

        :param part: The *part* parameter specifies a comma-separated list of one or more channel resource properties that the API response will include. If the parameter identifies a property that contains child properties, the child properties will be included in the response. For example, in a channel resource, the contentDetails property contains other properties, such as the uploads properties. As such, if you set *part=contentDetails*, the API response will also contain all of those nested properties. (required)
        :type part: List[str]
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param category_id: Return the channels within the specified guide category ID.
        :type category_id: str
        :param for_handle: Return the channel associated with a YouTube handle.
        :type for_handle: str
        :param for_username: Return the channel associated with a YouTube username.
        :type for_username: str
        :param hl: Stands for \"host language\". Specifies the localization language of the metadata to be filled into snippet.localized. The field is filled with the default metadata if there is no localization in the specified language. The parameter value must be a language code included in the list returned by the i18nLanguages.list method (e.g. en_US, es_MX).
        :type hl: str
        :param id: Return the channels with the specified IDs.
        :type id: List[str]
        :param managed_by_me: Return the channels managed by the authenticated user.
        :type managed_by_me: bool
        :param max_results: The *maxResults* parameter specifies the maximum number of items that should be returned in the result set.
        :type max_results: int
        :param mine: Return the ids of channels owned by the authenticated user.
        :type mine: bool
        :param my_subscribers: Return the channels subscribed to the authenticated user
        :type my_subscribers: bool
        :param on_behalf_of_content_owner: *Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.
        :type on_behalf_of_content_owner: str
        :param page_token: The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken and prevPageToken properties identify other pages that could be retrieved.
        :type page_token: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_channels_list_serialize(
            part=part,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            category_id=category_id,
            for_handle=for_handle,
            for_username=for_username,
            hl=hl,
            id=id,
            managed_by_me=managed_by_me,
            max_results=max_results,
            mine=mine,
            my_subscribers=my_subscribers,
            on_behalf_of_content_owner=on_behalf_of_content_owner,
            page_token=page_token,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ChannelListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def youtube_channels_list_without_preload_content(
        self,
        part: Annotated[List[StrictStr], Field(description="The *part* parameter specifies a comma-separated list of one or more channel resource properties that the API response will include. If the parameter identifies a property that contains child properties, the child properties will be included in the response. For example, in a channel resource, the contentDetails property contains other properties, such as the uploads properties. As such, if you set *part=contentDetails*, the API response will also contain all of those nested properties.")],
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        category_id: Annotated[Optional[StrictStr], Field(description="Return the channels within the specified guide category ID.")] = None,
        for_handle: Annotated[Optional[StrictStr], Field(description="Return the channel associated with a YouTube handle.")] = None,
        for_username: Annotated[Optional[StrictStr], Field(description="Return the channel associated with a YouTube username.")] = None,
        hl: Annotated[Optional[StrictStr], Field(description="Stands for \"host language\". Specifies the localization language of the metadata to be filled into snippet.localized. The field is filled with the default metadata if there is no localization in the specified language. The parameter value must be a language code included in the list returned by the i18nLanguages.list method (e.g. en_US, es_MX).")] = None,
        id: Annotated[Optional[List[StrictStr]], Field(description="Return the channels with the specified IDs.")] = None,
        managed_by_me: Annotated[Optional[StrictBool], Field(description="Return the channels managed by the authenticated user.")] = None,
        max_results: Annotated[Optional[Annotated[int, Field(le=50, strict=True, ge=0)]], Field(description="The *maxResults* parameter specifies the maximum number of items that should be returned in the result set.")] = None,
        mine: Annotated[Optional[StrictBool], Field(description="Return the ids of channels owned by the authenticated user.")] = None,
        my_subscribers: Annotated[Optional[StrictBool], Field(description="Return the channels subscribed to the authenticated user")] = None,
        on_behalf_of_content_owner: Annotated[Optional[StrictStr], Field(description="*Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.")] = None,
        page_token: Annotated[Optional[StrictStr], Field(description="The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken and prevPageToken properties identify other pages that could be retrieved.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """youtube_channels_list

        Retrieves a list of resources, possibly filtered.

        :param part: The *part* parameter specifies a comma-separated list of one or more channel resource properties that the API response will include. If the parameter identifies a property that contains child properties, the child properties will be included in the response. For example, in a channel resource, the contentDetails property contains other properties, such as the uploads properties. As such, if you set *part=contentDetails*, the API response will also contain all of those nested properties. (required)
        :type part: List[str]
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param category_id: Return the channels within the specified guide category ID.
        :type category_id: str
        :param for_handle: Return the channel associated with a YouTube handle.
        :type for_handle: str
        :param for_username: Return the channel associated with a YouTube username.
        :type for_username: str
        :param hl: Stands for \"host language\". Specifies the localization language of the metadata to be filled into snippet.localized. The field is filled with the default metadata if there is no localization in the specified language. The parameter value must be a language code included in the list returned by the i18nLanguages.list method (e.g. en_US, es_MX).
        :type hl: str
        :param id: Return the channels with the specified IDs.
        :type id: List[str]
        :param managed_by_me: Return the channels managed by the authenticated user.
        :type managed_by_me: bool
        :param max_results: The *maxResults* parameter specifies the maximum number of items that should be returned in the result set.
        :type max_results: int
        :param mine: Return the ids of channels owned by the authenticated user.
        :type mine: bool
        :param my_subscribers: Return the channels subscribed to the authenticated user
        :type my_subscribers: bool
        :param on_behalf_of_content_owner: *Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.
        :type on_behalf_of_content_owner: str
        :param page_token: The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken and prevPageToken properties identify other pages that could be retrieved.
        :type page_token: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_channels_list_serialize(
            part=part,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            category_id=category_id,
            for_handle=for_handle,
            for_username=for_username,
            hl=hl,
            id=id,
            managed_by_me=managed_by_me,
            max_results=max_results,
            mine=mine,
            my_subscribers=my_subscribers,
            on_behalf_of_content_owner=on_behalf_of_content_owner,
            page_token=page_token,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ChannelListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _youtube_channels_list_serialize(
        self,
        part,
        oauth_token,
        key,
        upload_type,
        quota_user,
        upload_protocol,
        param_callback,
        fields,
        xgafv,
        pretty_print,
        access_token,
        alt,
        category_id,
        for_handle,
        for_username,
        hl,
        id,
        managed_by_me,
        max_results,
        mine,
        my_subscribers,
        on_behalf_of_content_owner,
        page_token,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
            'part': 'multi',
            'id': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if oauth_token is not None:
            
            _query_params.append(('oauth_token', oauth_token))
            
        if key is not None:
            
            _query_params.append(('key', key))
            
        if upload_type is not None:
            
            _query_params.append(('uploadType', upload_type))
            
        if quota_user is not None:
            
            _query_params.append(('quotaUser', quota_user))
            
        if upload_protocol is not None:
            
            _query_params.append(('upload_protocol', upload_protocol))
            
        if param_callback is not None:
            
            _query_params.append(('callback', param_callback))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if xgafv is not None:
            
            _query_params.append(('$.xgafv', xgafv))
            
        if pretty_print is not None:
            
            _query_params.append(('prettyPrint', pretty_print))
            
        if access_token is not None:
            
            _query_params.append(('access_token', access_token))
            
        if alt is not None:
            
            _query_params.append(('alt', alt))
            
        if part is not None:
            
            _query_params.append(('part', part))
            
        if category_id is not None:
            
            _query_params.append(('categoryId', category_id))
            
        if for_handle is not None:
            
            _query_params.append(('forHandle', for_handle))
            
        if for_username is not None:
            
            _query_params.append(('forUsername', for_username))
            
        if hl is not None:
            
            _query_params.append(('hl', hl))
            
        if id is not None:
            
            _query_params.append(('id', id))
            
        if managed_by_me is not None:
            
            _query_params.append(('managedByMe', managed_by_me))
            
        if max_results is not None:
            
            _query_params.append(('maxResults', max_results))
            
        if mine is not None:
            
            _query_params.append(('mine', mine))
            
        if my_subscribers is not None:
            
            _query_params.append(('mySubscribers', my_subscribers))
            
        if on_behalf_of_content_owner is not None:
            
            _query_params.append(('onBehalfOfContentOwner', on_behalf_of_content_owner))
            
        if page_token is not None:
            
            _query_params.append(('pageToken', page_token))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'Oauth2c', 
            'Oauth2'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/youtube/v3/channels',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def youtube_channels_update(
        self,
        part: Annotated[List[StrictStr], Field(description="The *part* parameter serves two purposes in this operation. It identifies the properties that the write operation will set as well as the properties that the API response will include. The API currently only allows the parameter value to be set to either brandingSettings or invideoPromotion. (You cannot update both of those parts with a single request.) Note that this method overrides the existing values for all of the mutable properties that are contained in any parts that the parameter value specifies.")],
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        on_behalf_of_content_owner: Annotated[Optional[StrictStr], Field(description="The *onBehalfOfContentOwner* parameter indicates that the authenticated user is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The actual CMS account that the user authenticates with needs to be linked to the specified YouTube content owner.")] = None,
        channel: Optional[Channel] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> Channel:
        """youtube_channels_update

        Updates an existing resource.

        :param part: The *part* parameter serves two purposes in this operation. It identifies the properties that the write operation will set as well as the properties that the API response will include. The API currently only allows the parameter value to be set to either brandingSettings or invideoPromotion. (You cannot update both of those parts with a single request.) Note that this method overrides the existing values for all of the mutable properties that are contained in any parts that the parameter value specifies. (required)
        :type part: List[str]
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param on_behalf_of_content_owner: The *onBehalfOfContentOwner* parameter indicates that the authenticated user is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The actual CMS account that the user authenticates with needs to be linked to the specified YouTube content owner.
        :type on_behalf_of_content_owner: str
        :param channel:
        :type channel: Channel
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_channels_update_serialize(
            part=part,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            on_behalf_of_content_owner=on_behalf_of_content_owner,
            channel=channel,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Channel",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def youtube_channels_update_with_http_info(
        self,
        part: Annotated[List[StrictStr], Field(description="The *part* parameter serves two purposes in this operation. It identifies the properties that the write operation will set as well as the properties that the API response will include. The API currently only allows the parameter value to be set to either brandingSettings or invideoPromotion. (You cannot update both of those parts with a single request.) Note that this method overrides the existing values for all of the mutable properties that are contained in any parts that the parameter value specifies.")],
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        on_behalf_of_content_owner: Annotated[Optional[StrictStr], Field(description="The *onBehalfOfContentOwner* parameter indicates that the authenticated user is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The actual CMS account that the user authenticates with needs to be linked to the specified YouTube content owner.")] = None,
        channel: Optional[Channel] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[Channel]:
        """youtube_channels_update

        Updates an existing resource.

        :param part: The *part* parameter serves two purposes in this operation. It identifies the properties that the write operation will set as well as the properties that the API response will include. The API currently only allows the parameter value to be set to either brandingSettings or invideoPromotion. (You cannot update both of those parts with a single request.) Note that this method overrides the existing values for all of the mutable properties that are contained in any parts that the parameter value specifies. (required)
        :type part: List[str]
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param on_behalf_of_content_owner: The *onBehalfOfContentOwner* parameter indicates that the authenticated user is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The actual CMS account that the user authenticates with needs to be linked to the specified YouTube content owner.
        :type on_behalf_of_content_owner: str
        :param channel:
        :type channel: Channel
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_channels_update_serialize(
            part=part,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            on_behalf_of_content_owner=on_behalf_of_content_owner,
            channel=channel,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Channel",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def youtube_channels_update_without_preload_content(
        self,
        part: Annotated[List[StrictStr], Field(description="The *part* parameter serves two purposes in this operation. It identifies the properties that the write operation will set as well as the properties that the API response will include. The API currently only allows the parameter value to be set to either brandingSettings or invideoPromotion. (You cannot update both of those parts with a single request.) Note that this method overrides the existing values for all of the mutable properties that are contained in any parts that the parameter value specifies.")],
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        on_behalf_of_content_owner: Annotated[Optional[StrictStr], Field(description="The *onBehalfOfContentOwner* parameter indicates that the authenticated user is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The actual CMS account that the user authenticates with needs to be linked to the specified YouTube content owner.")] = None,
        channel: Optional[Channel] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """youtube_channels_update

        Updates an existing resource.

        :param part: The *part* parameter serves two purposes in this operation. It identifies the properties that the write operation will set as well as the properties that the API response will include. The API currently only allows the parameter value to be set to either brandingSettings or invideoPromotion. (You cannot update both of those parts with a single request.) Note that this method overrides the existing values for all of the mutable properties that are contained in any parts that the parameter value specifies. (required)
        :type part: List[str]
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param on_behalf_of_content_owner: The *onBehalfOfContentOwner* parameter indicates that the authenticated user is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The actual CMS account that the user authenticates with needs to be linked to the specified YouTube content owner.
        :type on_behalf_of_content_owner: str
        :param channel:
        :type channel: Channel
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_channels_update_serialize(
            part=part,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            on_behalf_of_content_owner=on_behalf_of_content_owner,
            channel=channel,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Channel",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _youtube_channels_update_serialize(
        self,
        part,
        oauth_token,
        key,
        upload_type,
        quota_user,
        upload_protocol,
        param_callback,
        fields,
        xgafv,
        pretty_print,
        access_token,
        alt,
        on_behalf_of_content_owner,
        channel,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
            'part': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if oauth_token is not None:
            
            _query_params.append(('oauth_token', oauth_token))
            
        if key is not None:
            
            _query_params.append(('key', key))
            
        if upload_type is not None:
            
            _query_params.append(('uploadType', upload_type))
            
        if quota_user is not None:
            
            _query_params.append(('quotaUser', quota_user))
            
        if upload_protocol is not None:
            
            _query_params.append(('upload_protocol', upload_protocol))
            
        if param_callback is not None:
            
            _query_params.append(('callback', param_callback))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if xgafv is not None:
            
            _query_params.append(('$.xgafv', xgafv))
            
        if pretty_print is not None:
            
            _query_params.append(('prettyPrint', pretty_print))
            
        if access_token is not None:
            
            _query_params.append(('access_token', access_token))
            
        if alt is not None:
            
            _query_params.append(('alt', alt))
            
        if part is not None:
            
            _query_params.append(('part', part))
            
        if on_behalf_of_content_owner is not None:
            
            _query_params.append(('onBehalfOfContentOwner', on_behalf_of_content_owner))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if channel is not None:
            _body_params = channel


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'Oauth2c', 
            'Oauth2'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/youtube/v3/channels',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.playlist_list_response import PlaylistListResponse

class TestPlaylistListResponse(unittest.TestCase):
    """PlaylistListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PlaylistListResponse:
        """Test PlaylistListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PlaylistListResponse`
        """
        model = PlaylistListResponse()
        if include_optional:
            return PlaylistListResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.playlist.Playlist(
                        content_details = youtube_ti.models.playlist_content_details.PlaylistContentDetails(
                            item_count = 56, ), 
                        etag = '', 
                        id = '', 
                        kind = 'youtube#playlist', 
                        localizations = youtube_ti.models.localizations.localizations(), 
                        player = youtube_ti.models.playlist_player.PlaylistPlayer(
                            embed_html = '', ), 
                        snippet = youtube_ti.models.playlist_snippet.PlaylistSnippet(
                            tags = [
                                ''
                                ], 
                            channel_id = '', 
                            channel_title = '', 
                            default_language = '', 
                            description = '', 
                            localized = youtube_ti.models.playlist_localization.PlaylistLocalization(
                                description = '', 
                                title = '', ), 
                            published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            thumbnail_video_id = '', 
                            thumbnails = youtube_ti.models.thumbnail_details.ThumbnailDetails(
                                default = youtube_ti.models.thumbnail.Thumbnail(
                                    height = 56, 
                                    url = '', 
                                    width = 56, ), 
                                high = youtube_ti.models.thumbnail.Thumbnail(
                                    height = 56, 
                                    url = '', 
                                    width = 56, ), 
                                maxres = , 
                                medium = , 
                                standard = , ), 
                            title = '', ), 
                        status = youtube_ti.models.playlist_status.PlaylistStatus(
                            podcast_status = 'enabled', 
                            privacy_status = 'public', ), )
                    ],
                kind = 'youtube#playlistListResponse',
                next_page_token = '',
                page_info = youtube_ti.models.page_info.PageInfo(
                    results_per_page = 56, 
                    total_results = 56, ),
                prev_page_token = '',
                token_pagination = None,
                visitor_id = ''
            )
        else:
            return PlaylistListResponse(
        )
        """

    def testPlaylistListResponse(self):
        """Test PlaylistListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.live_chat_message_snippet import LiveChatMessageSnippet

class TestLiveChatMessageSnippet(unittest.TestCase):
    """LiveChatMessageSnippet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LiveChatMessageSnippet:
        """Test LiveChatMessageSnippet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LiveChatMessageSnippet`
        """
        model = LiveChatMessageSnippet()
        if include_optional:
            return LiveChatMessageSnippet(
                author_channel_id = '',
                display_message = '',
                fan_funding_event_details = youtube_ti.models.live_chat_fan_funding_event_details.LiveChatFanFundingEventDetails(
                    amount_display_string = '', 
                    amount_micros = '', 
                    currency = '', 
                    user_comment = '', ),
                gift_membership_received_details = youtube_ti.models.live_chat_gift_membership_received_details.LiveChatGiftMembershipReceivedDetails(
                    associated_membership_gifting_message_id = '', 
                    gifter_channel_id = '', 
                    member_level_name = '', ),
                has_display_content = True,
                live_chat_id = '',
                member_milestone_chat_details = youtube_ti.models.live_chat_member_milestone_chat_details.LiveChatMemberMilestoneChatDetails(
                    member_level_name = '', 
                    member_month = 56, 
                    user_comment = '', ),
                membership_gifting_details = youtube_ti.models.live_chat_membership_gifting_details.LiveChatMembershipGiftingDetails(
                    gift_memberships_count = 56, 
                    gift_memberships_level_name = '', ),
                message_deleted_details = youtube_ti.models.live_chat_message_deleted_details.LiveChatMessageDeletedDetails(
                    deleted_message_id = '', ),
                message_retracted_details = youtube_ti.models.live_chat_message_retracted_details.LiveChatMessageRetractedDetails(
                    retracted_message_id = '', ),
                new_sponsor_details = youtube_ti.models.live_chat_new_sponsor_details.LiveChatNewSponsorDetails(
                    is_upgrade = True, 
                    member_level_name = '', ),
                poll_details = youtube_ti.models.live_chat_poll_details.LiveChatPollDetails(
                    metadata = youtube_ti.models.live_chat_poll_details_poll_metadata.LiveChatPollDetailsPollMetadata(
                        options = [
                            youtube_ti.models.live_chat_poll_details_poll_metadata_poll_option.LiveChatPollDetailsPollMetadataPollOption(
                                option_text = '', 
                                tally = '', )
                            ], 
                        question_text = '', ), 
                    status = 'unknown', ),
                published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                super_chat_details = youtube_ti.models.live_chat_super_chat_details.LiveChatSuperChatDetails(
                    amount_display_string = '', 
                    amount_micros = '', 
                    currency = '', 
                    tier = 56, 
                    user_comment = '', ),
                super_sticker_details = youtube_ti.models.live_chat_super_sticker_details.LiveChatSuperStickerDetails(
                    amount_display_string = '', 
                    amount_micros = '', 
                    currency = '', 
                    super_sticker_metadata = youtube_ti.models.super_sticker_metadata.SuperStickerMetadata(
                        alt_text = '', 
                        alt_text_language = '', 
                        sticker_id = '', ), 
                    tier = 56, ),
                text_message_details = youtube_ti.models.live_chat_text_message_details.LiveChatTextMessageDetails(
                    message_text = '', ),
                type = 'invalidType',
                user_banned_details = youtube_ti.models.live_chat_user_banned_message_details.LiveChatUserBannedMessageDetails(
                    ban_duration_seconds = '', 
                    ban_type = 'permanent', 
                    banned_user_details = youtube_ti.models.channel_profile_details.ChannelProfileDetails(
                        channel_id = '', 
                        channel_url = '', 
                        display_name = '', 
                        profile_image_url = '', ), )
            )
        else:
            return LiveChatMessageSnippet(
        )
        """

    def testLiveChatMessageSnippet(self):
        """Test LiveChatMessageSnippet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from youtube_ti.models.playlist_content_details import PlaylistContentDetails
from youtube_ti.models.playlist_player import PlaylistPlayer
from youtube_ti.models.playlist_snippet import PlaylistSnippet
from youtube_ti.models.playlist_status import PlaylistStatus
from typing import Optional, Set
from typing_extensions import Self

class Playlist(BaseModel):
    """
    A *playlist* resource represents a YouTube playlist. A playlist is a collection of videos that can be viewed sequentially and shared with other users. A playlist can contain up to 200 videos, and YouTube does not limit the number of playlists that each user creates. By default, playlists are publicly visible to other users, but playlists can be public or private. YouTube also uses playlists to identify special collections of videos for a channel, such as: - uploaded videos - favorite videos - positively rated (liked) videos - watch history - watch later To be more specific, these lists are associated with a channel, which is a collection of a person, group, or company's videos, playlists, and other YouTube information. You can retrieve the playlist IDs for each of these lists from the channel resource for a given channel. You can then use the playlistItems.list method to retrieve any of those lists. You can also add or remove items from those lists by calling the playlistItems.insert and playlistItems.delete methods.
    """ # noqa: E501
    content_details: Optional[PlaylistContentDetails] = Field(default=None, alias="contentDetails")
    etag: Optional[StrictStr] = Field(default=None, description="Etag of this resource.")
    id: Optional[StrictStr] = Field(default=None, description="The ID that YouTube uses to uniquely identify the playlist.")
    kind: Optional[StrictStr] = Field(default='youtube#playlist', description="Identifies what kind of resource this is. Value: the fixed string \"youtube#playlist\".")
    localizations: Optional[Dict[str, Any]] = Field(default=None, description="Localizations for different languages")
    player: Optional[PlaylistPlayer] = None
    snippet: Optional[PlaylistSnippet] = None
    status: Optional[PlaylistStatus] = None
    __properties: ClassVar[List[str]] = ["contentDetails", "etag", "id", "kind", "localizations", "player", "snippet", "status"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Playlist from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of content_details
        if self.content_details:
            _dict['contentDetails'] = self.content_details.to_dict()
        # override the default output from pydantic by calling `to_dict()` of player
        if self.player:
            _dict['player'] = self.player.to_dict()
        # override the default output from pydantic by calling `to_dict()` of snippet
        if self.snippet:
            _dict['snippet'] = self.snippet.to_dict()
        # override the default output from pydantic by calling `to_dict()` of status
        if self.status:
            _dict['status'] = self.status.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Playlist from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "contentDetails": PlaylistContentDetails.from_dict(obj["contentDetails"]) if obj.get("contentDetails") is not None else None,
            "etag": obj.get("etag"),
            "id": obj.get("id"),
            "kind": obj.get("kind") if obj.get("kind") is not None else 'youtube#playlist',
            "localizations": obj.get("localizations"),
            "player": PlaylistPlayer.from_dict(obj["player"]) if obj.get("player") is not None else None,
            "snippet": PlaylistSnippet.from_dict(obj["snippet"]) if obj.get("snippet") is not None else None,
            "status": PlaylistStatus.from_dict(obj["status"]) if obj.get("status") is not None else None
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.comment_list_response import CommentListResponse

class TestCommentListResponse(unittest.TestCase):
    """CommentListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CommentListResponse:
        """Test CommentListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CommentListResponse`
        """
        model = CommentListResponse()
        if include_optional:
            return CommentListResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.comment.Comment(
                        etag = '', 
                        id = '', 
                        kind = 'youtube#comment', 
                        snippet = youtube_ti.models.comment_snippet.CommentSnippet(
                            author_channel_id = youtube_ti.models.comment_snippet_author_channel_id.CommentSnippetAuthorChannelId(
                                value = '', ), 
                            author_channel_url = '', 
                            author_display_name = '', 
                            author_profile_image_url = '', 
                            can_rate = True, 
                            channel_id = '', 
                            like_count = 56, 
                            moderation_status = 'published', 
                            parent_id = '', 
                            published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            text_display = '', 
                            text_original = '', 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            video_id = '', 
                            viewer_rating = 'none', ), )
                    ],
                kind = 'youtube#commentListResponse',
                next_page_token = '',
                page_info = youtube_ti.models.page_info.PageInfo(
                    results_per_page = 56, 
                    total_results = 56, ),
                token_pagination = None,
                visitor_id = ''
            )
        else:
            return CommentListResponse(
        )
        """

    def testCommentListResponse(self):
        """Test CommentListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PlaylistImageSnippet(BaseModel):
    """
    A *playlistImage* resource identifies another resource, such as a image, that is associated with a playlist. In addition, the playlistImage resource contains details about the included resource that pertain specifically to how that resource is used in that playlist. YouTube uses playlists to identify special collections of videos for a channel, such as: - uploaded videos - favorite videos - positively rated (liked) videos - watch history To be more specific, these lists are associated with a channel, which is a collection of a person, group, or company's videos, playlists, and other YouTube information. You can retrieve the playlist IDs for each of these lists from the channel resource for a given channel. You can then use the playlistImages.list method to retrieve image data for any of those playlists. You can also add or remove images from those lists by calling the playlistImages.insert and playlistImages.delete methods.
    """ # noqa: E501
    height: Optional[StrictInt] = Field(default=None, description="The image height.")
    playlist_id: Optional[StrictStr] = Field(default=None, description="The Playlist ID of the playlist this image is associated with.", alias="playlistId")
    type: Optional[StrictStr] = Field(default=None, description="The image type.")
    width: Optional[StrictInt] = Field(default=None, description="The image width.")
    __properties: ClassVar[List[str]] = ["height", "playlistId", "type", "width"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['hero']):
            raise ValueError("must be one of enum values ('hero')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PlaylistImageSnippet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PlaylistImageSnippet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "height": obj.get("height"),
            "playlistId": obj.get("playlistId"),
            "type": obj.get("type"),
            "width": obj.get("width")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.channel_list_response import ChannelListResponse

class TestChannelListResponse(unittest.TestCase):
    """ChannelListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChannelListResponse:
        """Test ChannelListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChannelListResponse`
        """
        model = ChannelListResponse()
        if include_optional:
            return ChannelListResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.channel.Channel(
                        audit_details = youtube_ti.models.channel_audit_details.ChannelAuditDetails(
                            community_guidelines_good_standing = True, 
                            content_id_claims_good_standing = True, 
                            copyright_strikes_good_standing = True, ), 
                        branding_settings = youtube_ti.models.channel_branding_settings.ChannelBrandingSettings(
                            channel = youtube_ti.models.channel_settings.ChannelSettings(
                                country = '', 
                                default_language = '', 
                                default_tab = '', 
                                description = '', 
                                featured_channels_title = '', 
                                featured_channels_urls = [
                                    ''
                                    ], 
                                keywords = '', 
                                moderate_comments = True, 
                                profile_color = '', 
                                show_browse_view = True, 
                                show_related_channels = True, 
                                title = '', 
                                tracking_analytics_account_id = '', 
                                unsubscribed_trailer = '', ), 
                            hints = [
                                youtube_ti.models.property_value.PropertyValue(
                                    property = '', 
                                    value = '', )
                                ], 
                            image = youtube_ti.models.image_settings.ImageSettings(
                                background_image_url = youtube_ti.models.localized_property.LocalizedProperty(
                                    default = '', 
                                    default_language = youtube_ti.models.language_tag.LanguageTag(
                                        value = '', ), 
                                    localized = [
                                        youtube_ti.models.localized_string.LocalizedString(
                                            language = '', 
                                            value = '', )
                                        ], ), 
                                banner_external_url = '', 
                                banner_image_url = '', 
                                banner_mobile_extra_hd_image_url = '', 
                                banner_mobile_hd_image_url = '', 
                                banner_mobile_image_url = '', 
                                banner_mobile_low_image_url = '', 
                                banner_mobile_medium_hd_image_url = '', 
                                banner_tablet_extra_hd_image_url = '', 
                                banner_tablet_hd_image_url = '', 
                                banner_tablet_image_url = '', 
                                banner_tablet_low_image_url = '', 
                                banner_tv_high_image_url = '', 
                                banner_tv_image_url = '', 
                                banner_tv_low_image_url = '', 
                                banner_tv_medium_image_url = '', 
                                large_branded_banner_image_imap_script = youtube_ti.models.localized_property.LocalizedProperty(
                                    default = '', ), 
                                large_branded_banner_image_url = , 
                                small_branded_banner_image_imap_script = , 
                                small_branded_banner_image_url = , 
                                tracking_image_url = '', 
                                watch_icon_image_url = '', ), 
                            watch = youtube_ti.models.watch_settings.WatchSettings(
                                background_color = '', 
                                featured_playlist_id = '', 
                                text_color = '', ), ), 
                        content_details = youtube_ti.models.channel_content_details.ChannelContentDetails(
                            related_playlists = youtube_ti.models.channel_content_details_related_playlists.ChannelContentDetails_relatedPlaylists(
                                favorites = '', 
                                likes = '', 
                                uploads = '', 
                                watch_history = '', 
                                watch_later = '', ), ), 
                        content_owner_details = youtube_ti.models.channel_content_owner_details.ChannelContentOwnerDetails(
                            content_owner = '', 
                            time_linked = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        conversion_pings = youtube_ti.models.channel_conversion_pings.ChannelConversionPings(
                            pings = [
                                youtube_ti.models.channel_conversion_ping.ChannelConversionPing(
                                    context = 'subscribe', 
                                    conversion_url = '', )
                                ], ), 
                        etag = '', 
                        id = '', 
                        kind = 'youtube#channel', 
                        localizations = youtube_ti.models.localizations.localizations(), 
                        snippet = youtube_ti.models.channel_snippet.ChannelSnippet(
                            country = '', 
                            custom_url = '', 
                            description = '', 
                            published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            thumbnails = youtube_ti.models.thumbnail_details.ThumbnailDetails(
                                default = youtube_ti.models.thumbnail.Thumbnail(
                                    height = 56, 
                                    url = '', 
                                    width = 56, ), 
                                high = youtube_ti.models.thumbnail.Thumbnail(
                                    height = 56, 
                                    url = '', 
                                    width = 56, ), 
                                maxres = , 
                                medium = , 
                                standard = , ), 
                            title = '', ), 
                        statistics = youtube_ti.models.channel_statistics.ChannelStatistics(
                            comment_count = '', 
                            hidden_subscriber_count = True, 
                            subscriber_count = '', 
                            video_count = '', 
                            view_count = '', ), 
                        status = youtube_ti.models.channel_status.ChannelStatus(
                            is_channel_monetization_enabled = True, 
                            is_linked = True, 
                            long_uploads_status = 'longUploadsUnspecified', 
                            made_for_kids = True, 
                            privacy_status = 'public', 
                            self_declared_made_for_kids = True, ), 
                        topic_details = youtube_ti.models.channel_topic_details.ChannelTopicDetails(
                            topic_categories = [
                                ''
                                ], 
                            topic_ids = [
                                ''
                                ], ), )
                    ],
                kind = 'youtube#channelListResponse',
                next_page_token = '',
                page_info = youtube_ti.models.page_info.PageInfo(
                    results_per_page = 56, 
                    total_results = 56, ),
                prev_page_token = '',
                token_pagination = None,
                visitor_id = ''
            )
        else:
            return ChannelListResponse(
        )
        """

    def testChannelListResponse(self):
        """Test ChannelListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.memberships_level_list_response import MembershipsLevelListResponse

class TestMembershipsLevelListResponse(unittest.TestCase):
    """MembershipsLevelListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MembershipsLevelListResponse:
        """Test MembershipsLevelListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MembershipsLevelListResponse`
        """
        model = MembershipsLevelListResponse()
        if include_optional:
            return MembershipsLevelListResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.memberships_level.MembershipsLevel(
                        etag = '', 
                        id = '', 
                        kind = 'youtube#membershipsLevel', 
                        snippet = youtube_ti.models.memberships_level_snippet.MembershipsLevelSnippet(
                            creator_channel_id = '', 
                            level_details = youtube_ti.models.level_details.LevelDetails(
                                display_name = '', ), ), )
                    ],
                kind = 'youtube#membershipsLevelListResponse',
                visitor_id = ''
            )
        else:
            return MembershipsLevelListResponse(
        )
        """

    def testMembershipsLevelListResponse(self):
        """Test MembershipsLevelListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
